==> haskell-simple-reflect-0.3.3-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-reflect.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-reflect
version:              0.3.3
visibility:           public
id:                   simple-reflect-0.3.3-Gtodyc0HklS7fcoRZfRAjv
key:                  simple-reflect-0.3.3-Gtodyc0HklS7fcoRZfRAjv
license:              BSD-3-Clause
maintainer:           twanvl@gmail.com
author:               Twan van Laarhoven
homepage:
    http://twanvl.nl/blog/haskell/simple-reflection-of-expressions

synopsis:             Simple reflection of expressions containing variables
description:
    This package allows simple reflection of expressions containing variables.
    Reflection here means that a Haskell expression is turned into a string.
    The primary aim of this package is teaching and understanding;
    there are no options for manipulating the reflected expressions beyond showing them.

category:             Debug
abi:                  50a1e8868638a32009799888419804b9
exposed:              True
exposed-modules:
    Debug.SimpleReflect Debug.SimpleReflect.Expr
    Debug.SimpleReflect.Vars

import-dirs:          /usr/lib/ghc-9.0.1/site-local/simple-reflect-0.3.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/simple-reflect-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/simple-reflect-0.3.3
hs-libraries:         HSsimple-reflect-0.3.3-Gtodyc0HklS7fcoRZfRAjv
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-simple-reflect/html/simple-reflect.haddock

haddock-html:         /usr/share/doc/haskell-simple-reflect/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-reflect-0.3.3-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-reflect.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 simple-reflect
version:              0.3.3
visibility:           public
id:                   simple-reflect-0.3.3-63UyWZBqImk9E4Nw4bto0L
key:                  simple-reflect-0.3.3-63UyWZBqImk9E4Nw4bto0L
license:              BSD-3-Clause
maintainer:           twanvl@gmail.com
author:               Twan van Laarhoven
homepage:
    http://twanvl.nl/blog/haskell/simple-reflection-of-expressions

synopsis:             Simple reflection of expressions containing variables
description:
    This package allows simple reflection of expressions containing variables.
    Reflection here means that a Haskell expression is turned into a string.
    The primary aim of this package is teaching and understanding;
    there are no options for manipulating the reflected expressions beyond showing them.

category:             Debug
abi:                  cf2d950f864f94bf7b3ac452ce5b67b6
exposed:              True
exposed-modules:
    Debug.SimpleReflect Debug.SimpleReflect.Expr
    Debug.SimpleReflect.Vars

import-dirs:          /usr/lib/ghc-9.0.2/site-local/simple-reflect-0.3.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/simple-reflect-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/simple-reflect-0.3.3
hs-libraries:         HSsimple-reflect-0.3.3-63UyWZBqImk9E4Nw4bto0L
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-simple-reflect/html/simple-reflect.haddock

haddock-html:         /usr/share/doc/haskell-simple-reflect/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
